chordtools.Chord
================

.. inheritance-diagram:: abjad.tools.chordtools.Chord.Chord.Chord
   :private-bases:

.. autoclass:: abjad.tools.chordtools.Chord.Chord.Chord

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.chordtools.Chord.Chord.Chord.duration_in_seconds

   .. note:: Inherited from :py:class:`leaftools.Leaf <abjad.tools.leaftools.Leaf.Leaf.Leaf>`

.. autoattribute:: abjad.tools.chordtools.Chord.Chord.Chord.fingered_pitches

.. autoattribute:: abjad.tools.chordtools.Chord.Chord.Chord.format

   .. note:: Inherited from :py:class:`leaftools.Leaf <abjad.tools.leaftools.Leaf.Leaf.Leaf>`

.. autoattribute:: abjad.tools.chordtools.Chord.Chord.Chord.leaf_index

   .. note:: Inherited from :py:class:`leaftools.Leaf <abjad.tools.leaftools.Leaf.Leaf.Leaf>`

.. autoattribute:: abjad.tools.chordtools.Chord.Chord.Chord.marks

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.chordtools.Chord.Chord.Chord.multiplied_duration

   .. note:: Inherited from :py:class:`leaftools.Leaf <abjad.tools.leaftools.Leaf.Leaf.Leaf>`

.. autoattribute:: abjad.tools.chordtools.Chord.Chord.Chord.override

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.chordtools.Chord.Chord.Chord.parent

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.chordtools.Chord.Chord.Chord.preprolated_duration

   .. note:: Inherited from :py:class:`leaftools.Leaf <abjad.tools.leaftools.Leaf.Leaf.Leaf>`

.. autoattribute:: abjad.tools.chordtools.Chord.Chord.Chord.prolated_duration

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.chordtools.Chord.Chord.Chord.prolation

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.chordtools.Chord.Chord.Chord.set

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.chordtools.Chord.Chord.Chord.sounding_pitches

.. autoattribute:: abjad.tools.chordtools.Chord.Chord.Chord.spanners

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.chordtools.Chord.Chord.Chord.duration_multiplier

   .. note:: Inherited from :py:class:`leaftools.Leaf <abjad.tools.leaftools.Leaf.Leaf.Leaf>`

.. autoattribute:: abjad.tools.chordtools.Chord.Chord.Chord.note_heads

.. autoattribute:: abjad.tools.chordtools.Chord.Chord.Chord.written_duration

   .. note:: Inherited from :py:class:`leaftools.Leaf <abjad.tools.leaftools.Leaf.Leaf.Leaf>`

.. autoattribute:: abjad.tools.chordtools.Chord.Chord.Chord.written_pitch_indication_is_at_sounding_pitch

   .. note:: Inherited from :py:class:`leaftools.Leaf <abjad.tools.leaftools.Leaf.Leaf.Leaf>`

.. autoattribute:: abjad.tools.chordtools.Chord.Chord.Chord.written_pitch_indication_is_nonsemantic

   .. note:: Inherited from :py:class:`leaftools.Leaf <abjad.tools.leaftools.Leaf.Leaf.Leaf>`

.. autoattribute:: abjad.tools.chordtools.Chord.Chord.Chord.written_pitches

Methods
-------

.. automethod:: abjad.tools.chordtools.Chord.Chord.Chord.append

.. automethod:: abjad.tools.chordtools.Chord.Chord.Chord.clear

.. automethod:: abjad.tools.chordtools.Chord.Chord.Chord.extend

.. automethod:: abjad.tools.chordtools.Chord.Chord.Chord.pop

.. automethod:: abjad.tools.chordtools.Chord.Chord.Chord.remove

Special Methods
---------------

.. automethod:: abjad.tools.chordtools.Chord.Chord.Chord.__and__

   .. note:: Inherited from :py:class:`leaftools.Leaf <abjad.tools.leaftools.Leaf.Leaf.Leaf>`

.. automethod:: abjad.tools.chordtools.Chord.Chord.Chord.__contains__

.. automethod:: abjad.tools.chordtools.Chord.Chord.Chord.__delattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.chordtools.Chord.Chord.Chord.__delitem__

.. automethod:: abjad.tools.chordtools.Chord.Chord.Chord.__eq__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.chordtools.Chord.Chord.Chord.__ge__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.chordtools.Chord.Chord.Chord.__getitem__

.. automethod:: abjad.tools.chordtools.Chord.Chord.Chord.__gt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.chordtools.Chord.Chord.Chord.__hash__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.chordtools.Chord.Chord.Chord.__le__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.chordtools.Chord.Chord.Chord.__len__

.. automethod:: abjad.tools.chordtools.Chord.Chord.Chord.__lt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.chordtools.Chord.Chord.Chord.__mul__

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. automethod:: abjad.tools.chordtools.Chord.Chord.Chord.__ne__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.chordtools.Chord.Chord.Chord.__or__

   .. note:: Inherited from :py:class:`leaftools.Leaf <abjad.tools.leaftools.Leaf.Leaf.Leaf>`

.. automethod:: abjad.tools.chordtools.Chord.Chord.Chord.__repr__

   .. note:: Inherited from :py:class:`leaftools.Leaf <abjad.tools.leaftools.Leaf.Leaf.Leaf>`

.. automethod:: abjad.tools.chordtools.Chord.Chord.Chord.__rmul__

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. automethod:: abjad.tools.chordtools.Chord.Chord.Chord.__setattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.chordtools.Chord.Chord.Chord.__setitem__

.. automethod:: abjad.tools.chordtools.Chord.Chord.Chord.__str__

   .. note:: Inherited from :py:class:`leaftools.Leaf <abjad.tools.leaftools.Leaf.Leaf.Leaf>`

.. automethod:: abjad.tools.chordtools.Chord.Chord.Chord.__sub__

   .. note:: Inherited from :py:class:`leaftools.Leaf <abjad.tools.leaftools.Leaf.Leaf.Leaf>`

.. automethod:: abjad.tools.chordtools.Chord.Chord.Chord.__xor__

   .. note:: Inherited from :py:class:`leaftools.Leaf <abjad.tools.leaftools.Leaf.Leaf.Leaf>`
